@@ -115,6 +115,24 @@ class BlobNotFound(NotFound):
         )
 
 
+class BlobInvalid(ParseError):
+    """Exception to render a 400 with the code 'BLOB_UNKNOWN'"""
+
+    def __init__(self, digest):
+        """Initialize the exception with the blob digest."""
+        super().__init__(
+            detail={
+                "errors": [
+                    {
+                        "code": "BLOB_UNKNOWN",
+                        "message": "blob unknown to registry",
+                        "detail": {"digest": digest},
+                    }
+                ]
+            }
+        )
+
+
 class ManifestNotFound(NotFound):
     """Exception to render a 404 with the code 'MANIFEST_UNKNOWN'"""
 
@@ -133,6 +151,24 @@ class ManifestNotFound(NotFound):
         )
 
 
+class ManifestInvalid(ParseError):
+    """Exception to render a 400 with the code 'MANIFEST_INVALID'"""
+
+    def __init__(self, digest):
+        """Initialize the exception with the manifest digest."""
+        super().__init__(
+            detail={
+                "errors": [
+                    {
+                        "code": "MANIFEST_INVALID",
+                        "message": "manifest invalid",
+                        "detail": {"digest": digest},
+                    }
+                ]
+            }
+        )
+
+
 class ContentRenderer(BaseRenderer):
     """
     Rendered class for rendering Manifest and Blob responses.
@@ -153,7 +189,7 @@ class UploadResponse(Response):
     This response object provides information about Uploads during 'push' operations.
     """
 
-    def __init__(self, upload, path, request):
+    def __init__(self, upload, path, request, status=202):
         """
         Args:
             upload (pulp_container.app.models.Upload): An Upload model used to generate the
@@ -162,13 +198,17 @@ class UploadResponse(Response):
             request (rest_framework.request.Request): Request object not used by this
                 implementation of Response.
         """
+        if upload.size == 0:
+            offset = 0
+        else:
+            offset = int(upload.size - 1)
         headers = {
             "Docker-Upload-UUID": upload.pk,
             "Location": f"/v2/{path}/blobs/uploads/{upload.pk}",
-            "Range": "0-{offset}".format(offset=int(upload.size - 1)),
+            "Range": "0-{offset}".format(offset=offset),
             "Content-Length": 0,
         }
-        super().__init__(headers=headers, status=202)
+        super().__init__(headers=headers, status=status)
 
 
 class ManifestResponse(Response):
@@ -208,17 +248,10 @@ class BlobResponse(Response):
                 implementation of Response.
             status (int): Status code to send with the response.
         """
-        artifact = blob._artifacts.get()
-        size = artifact.size
-
         headers = {
             "Docker-Content-Digest": blob.digest,
             "Location": "/v2/{path}/blobs/{digest}".format(path=path, digest=blob.digest),
-            "Etag": blob.digest,
-            "Range": "0-{offset}".format(offset=int(size)),
             "Content-Length": 0,
-            "Content-Type": "application/octet-stream",
-            "Connection": "close",
         }
         super().__init__(headers=headers, status=status)
 
@@ -627,7 +660,7 @@ class BlobUploads(ContainerRegistryApiMixin, ViewSet):
             upload.size += chunk.size
             upload.save()
 
-        return UploadResponse(upload=upload, path=path, request=request)
+        return UploadResponse(upload=upload, path=path, request=request, status=204)
 
     def put(self, request, path, pk=None):
         """
@@ -647,7 +680,7 @@ class BlobUploads(ContainerRegistryApiMixin, ViewSet):
             # Upload has been deleted => task has started or even finished
             task = Task.objects.filter(
                 name__endswith="add_and_remove",
-                reserved_resources_record__contains=[f"shared:upload:{pk}"],
+                reserved_resources_record=[f"upload:{pk}"],
             ).last()
             if not task:
                 # No upload and no task for it => the upload probably never existed
@@ -819,14 +852,34 @@ class Manifests(RedirectsMixin, ContainerRegistryApiMixin, ViewSet):
         # iterate over all the layers and create
         chunk = request.META["wsgi.input"]
         artifact = self.receive_artifact(chunk)
+        manifest_digest = "sha256:{id}".format(id=artifact.sha256)
         with storage.open(artifact.file.name) as artifact_file:
             raw_data = artifact_file.read()
         content_data = json.loads(raw_data)
+        # oci format might not contain mediaType in the manifest.json, docker should
+        # hence need to check request content type
+        if request.content_type not in (
+            models.MEDIA_TYPE.MANIFEST_V2,
+            models.MEDIA_TYPE.MANIFEST_OCI,
+        ):
+            # we suport only v2 docker/oci schema upload
+            raise ManifestInvalid(digest=manifest_digest)
+        # both docker/oci format should contain config, digest, mediaType, size
         config_layer = content_data.get("config")
-        config_blob = models.Blob.objects.get(digest=config_layer.get("digest"))
+        try:
+            config_digest = config_layer.get("digest")
+            config_blob = models.Blob.objects.get(digest=config_digest)
+        except models.Blob.DoesNotExist:
+            raise BlobNotFound(digest=config_digest)
+        config_media_type = config_layer.get("mediaType")
+        if config_media_type not in (
+            models.MEDIA_TYPE.CONFIG_BLOB,
+            models.MEDIA_TYPE.CONFIG_BLOB_OCI,
+        ):
+            raise BlobInvalid(digest=config_blob.digest)
 
         manifest = models.Manifest(
-            digest="sha256:{id}".format(id=artifact.sha256),
+            digest=manifest_digest,
             schema_version=2,
             media_type=request.content_type,
             config_blob=config_blob,
@@ -846,12 +899,19 @@ class Manifests(RedirectsMixin, ContainerRegistryApiMixin, ViewSet):
                 ca.save(update_fields=["artifact"])
         # both docker/oci format should contain layers, digest, media_type, size
         layers = content_data.get("layers")
-        blobs = []
+        blobs = {}
         for layer in layers:
-            blobs.append(layer.get("digest"))
-        blobs_qs = models.Blob.objects.filter(digest__in=blobs)
+            blobs[layer.get("digest")] = layer.get("mediaType")
+        blobs_qs = models.Blob.objects.filter(digest__in=blobs.keys())
         thru = []
         for blob in blobs_qs:
+            # ensure there are no foreign layers
+            blob_media_type = blobs[blob.digest]
+            if blob_media_type not in (
+                models.MEDIA_TYPE.REGULAR_BLOB,
+                models.MEDIA_TYPE.REGULAR_BLOB_OCI,
+            ):
+                raise BlobInvalid(digest=blob.digest)
             thru.append(models.BlobManifest(manifest=manifest, manifest_blob=blob))
         models.BlobManifest.objects.bulk_create(objs=thru, ignore_conflicts=True, batch_size=1000)
         tag = models.Tag(name=pk, tagged_manifest=manifest)
