@@ -20,14 +20,14 @@ from pulp_container.tests.functional.utils import (
     core_client,
     gen_container_client,
     gen_container_remote,
-    get_blobsums_from_remote_registry,
+    get_docker_hub_remote_blobsums,
     BearerTokenAuth,
     AuthenticationHeaderQueries,
 )
 from pulp_container.tests.functional.constants import (
     CONTAINER_CONTENT_NAME,
-    REGISTRY_V2_REPO_HELLO_WORLD,
-    PULP_HELLO_WORLD_LINUX_TAG,
+    REPO_UPSTREAM_NAME,
+    REPO_UPSTREAM_TAG,
 )
 from pulp_container.constants import EMPTY_BLOB, MEDIA_TYPE
 
@@ -139,7 +139,7 @@ class PullContentTestCase(unittest.TestCase):
         # Assert that at least one layer is synced from remote:latest
         # and the checksum matched with remote
         self.assertTrue(
-            any([checksum in checksums for checksum in get_blobsums_from_remote_registry()]),
+            any([result["blobSum"] in checksums for result in get_docker_hub_remote_blobsums()]),
             "Cannot find a matching layer on remote registry.",
         )
 
@@ -236,11 +236,11 @@ class PullContentTestCase(unittest.TestCase):
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD)
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.pull(REPO_UPSTREAM_NAME)
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
-        registry.rmi(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.rmi(REPO_UPSTREAM_NAME)
 
     def test_pull_image_from_repository_version(self):
         """Verify that a client can pull the image from Pulp.
@@ -260,11 +260,11 @@ class PullContentTestCase(unittest.TestCase):
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD)
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.pull(REPO_UPSTREAM_NAME)
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
-        registry.rmi(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.rmi(REPO_UPSTREAM_NAME)
 
     def test_pull_image_with_tag(self):
         """Verify that a client can pull the image from Pulp with a tag.
@@ -280,18 +280,16 @@ class PullContentTestCase(unittest.TestCase):
 
         local_url = (
             urljoin(self.cfg.get_base_url(), self.distribution_with_repo.base_path)
-            + PULP_HELLO_WORLD_LINUX_TAG
+            + REPO_UPSTREAM_TAG
         )
 
         registry.pull(local_url)
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
-        self.teardown_cleanups.append(
-            (registry.rmi, REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
-        )
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
+        registry.pull(REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG)
+        self.teardown_cleanups.append((registry.rmi, REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG))
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
 
@@ -410,7 +408,7 @@ class PullOnDemandContentTestCase(unittest.TestCase):
         # Assert that at least one layer is synced from remote:latest
         # and the checksum matched with remote
         self.assertTrue(
-            any([checksum in checksums for checksum in get_blobsums_from_remote_registry()]),
+            any([result["blobSum"] in checksums for result in get_docker_hub_remote_blobsums()]),
             "Cannot find a matching layer on remote registry.",
         )
 
@@ -433,15 +431,15 @@ class PullOnDemandContentTestCase(unittest.TestCase):
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD)
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.pull(REPO_UPSTREAM_NAME)
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
 
         new_artifact_count = self.artifacts_api.list().count
         self.assertGreater(new_artifact_count, self.artifact_count)
 
-        registry.rmi(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.rmi(REPO_UPSTREAM_NAME)
 
     def test_pull_image_from_repository_version(self):
         """Verify that a client can pull the image from Pulp (on-demand).
@@ -461,11 +459,11 @@ class PullOnDemandContentTestCase(unittest.TestCase):
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD)
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.pull(REPO_UPSTREAM_NAME)
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
-        registry.rmi(REGISTRY_V2_REPO_HELLO_WORLD)
+        registry.rmi(REPO_UPSTREAM_NAME)
 
     def test_pull_image_with_tag(self):
         """Verify that a client can pull the image from Pulp with a tag (on-demand).
@@ -481,17 +479,15 @@ class PullOnDemandContentTestCase(unittest.TestCase):
 
         local_url = (
             urljoin(self.cfg.get_base_url(), self.distribution_with_repo.base_path)
-            + PULP_HELLO_WORLD_LINUX_TAG
+            + REPO_UPSTREAM_TAG
         )
 
         registry.pull(local_url)
         self.teardown_cleanups.append((registry.rmi, local_url))
         local_image = registry.inspect(local_url)
 
-        registry.pull(REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
-        self.teardown_cleanups.append(
-            (registry.rmi, REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
-        )
-        remote_image = registry.inspect(REGISTRY_V2_REPO_HELLO_WORLD + PULP_HELLO_WORLD_LINUX_TAG)
+        registry.pull(REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG)
+        self.teardown_cleanups.append((registry.rmi, REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG))
+        remote_image = registry.inspect(REPO_UPSTREAM_NAME + REPO_UPSTREAM_TAG)
 
         self.assertEqual(local_image[0]["Id"], remote_image[0]["Id"])
